#
# spec file for package kfilemetadata5
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without ffmpeg
%define qt5_version 5.15.2
%bcond_without released
Name:           kfilemetadata5
Version:        5.116.0
Release:        1.3
Summary:        Library for extracting Metadata
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND LGPL-3.0-only
URL:            https://www.kde.org
Source:         kfilemetadata-%{version}.tar.xz
%if %{with released}
Source1:        kfilemetadata-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  libattr-devel
BuildRequires:  libepub-devel
BuildRequires:  libexiv2-devel >= 0.21
BuildRequires:  pkgconfig
BuildRequires:  taglib-devel >= 1.9
BuildRequires:  cmake(KF5Archive) >= %{_kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5Config) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(QMobipocket)
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}
BuildRequires:  cmake(Qt5Xml) >= %{qt5_version}
BuildRequires:  pkgconfig(poppler-qt5)
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
%endif

%description
A library for extracting file metadata.

%package devel
Summary:        Development package for kfilemetadata
Requires:       %{name} = %{version}
Requires:       cmake(Qt5Core) >= %{qt5_version}

%description devel
A library for extracting file metadata. Development files

%lang_package

%prep
%autosetup -p1 -n kfilemetadata-%{version}

%build
%cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
%cmake_build

%install
%kf5_makeinstall -C build

%{kf5_find_lang}

%ldconfig_scriptlets

%files
%license LICENSES/*
%{_kf5_debugdir}/*.categories
%{_kf5_debugdir}/*.renamecategories
%{_kf5_libdir}/libKF5FileMetaData.so.*
%{_kf5_plugindir}/

%files devel
%{_kf5_includedir}/KFileMetaData/
%{_kf5_libdir}/cmake/KF5FileMetaData/
%{_kf5_libdir}/libKF5FileMetaData.so
%{_kf5_mkspecsdir}/qt_KFileMetaData.pri

%files lang -f %{name}.lang

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- Changes since 5.115.0:
  * fix handling of attribute namespacing
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- Changes since 5.114.0:
  * Fix compilation with latest TagLib git master
  * Fix build with taglib 2
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- Changes since 5.112.0:
  * Run dump utility as a test case
  * Output generic file types from dump utility
  * Check if file path passed to dump utility is a readable file
  * [FFmpegExtractor] Bail out on first missing component during find_package
  * Bump minimum Exiv2 version to 0.26
  * [TaglibExtractor] Add support for Ogg stream with FLAC (audio/x-flac+ogg)
  * Generate fromName hash table programmatically from PropertyInfo table
  * Use proxy class for lowercase property name lookup
  * Reduce PropertyInfo::fromName overhead
  * [FFMpegExtractor] Support and check video/vnd.avi
  * [TaglibExtractor] Adapt code to SMI changes for audio/x-wav -> /vnd.wave
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Remove awkward warning message also from Exiv2 autotests
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
  * Reapply ReplayGain changes
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- Changes since 5.106.0:
  * Cleanup property name/id mapping test
  * Add method to export list of all Property names.
  * Reduce PropertyInfo construction overhead
  * Add benchmark for PropertyInfo instantiation
  * Fix build with exiv2 >= 0.28
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * Test HEIF in Exiv2Extractor
  * Test JXL in Exiv2Extractor, extend JPEG coverage
  * Move static private helper out of Exiv2ExtractorTest class
  * Clean up Exiv2/C++14 warning message
  * Remove usage of deprecated MP4::ItemListMap in taglib extractor
  * Disable external extractor/writer test on Windows
  * Modernize and extend CMake check for Python3
  * Extend dignostics for taglib autotests
  * Make fb2 extractor compilation dependent on KF5Archive
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- No code change since 5.104.0
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * Mobi extractor: only extract what is asked (kde#465006)
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- Changes since 5.102.0:
  * Also add external extractors to vector of all plugins (kde#463598)
  * Fix loading of external extractors and writers (kde#463598)
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * odfextractor: Add support for Open Document Graphics
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * FFmpegExtrator: Try stream metadata if no global metadata is available
  * office2007extractor: Extract text document line count
  * office2007extractor: Update docx to include more properties
  * Add FictionBook2 extractor
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * OdfExtractorTest: Add test cases for Flat XML documents
  * OdfExtractor: Only go looking for textual content in office:body
  * OdfExtractor: Support "Flat XML" variants
  * PngExtractor: Add autotest
  * PngExtractor: Only extract metadata when it was asked for
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * Add Qt 6 Windows CI
  * Dawid Wróbel .gitlab-ci.yml: enable static builds
  * Fix compilation of tests in static builds (kde#459344)
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Add FreeBSD Qt6 CI support
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * Remove reviewboardrc
  * Add PNG extractor
  * dump tool: Print extractor name
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- No code change since 5.95.0
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- No code change since 5.94.0
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * Check executables exist in PATH before passing them to QProcess
  * Add windows CI
  * install version header
  * Create version header file
  * exiv2extractor: add support for Canon CR3 raw image
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Require unittests to pass for CI jobs to pass
  * exiv2extractor: add support for avif, heif, jpeg xl
* Tue Mar 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Build the optional mobipocket extractor.
  QMobipocket only depends on Qt and shouldn't cause any issue.
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Port to KPluginMetaData::findPlugins for plugin querying
  * enable mobipocket extractor by default
  * Use std::unique_ptr to manage lifetime of d-ptr
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Also build the actual Poppler extractor with Qt6, not just its unit test
  * make TypInfo comparison const
  * Install plugins in kf<version>
  * deprecate image extraction via embeddedimagedata
  * Add CI qt6 support
  * Apply Samir fix about LIBEXEC_INSTALL_DIR
  * More changes to make it build against Qt6
  * Make it compiles against qt6
  * Make the Poppler extractor compatible with the Qt6-based Poppler as well
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Optimize README formatting for api.kde.org
  * USe const'ref
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * KFileMetaData::Property: Deprecate toVariantMap and toPropertyMap methods
  * Port deprecated QMap methods to QMultiMap
  * Put code of public header depending on deprecated Qt API in deprecation wrapper
  * [PopplerExtractor] extract pageCount
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * Fix wrong testcase.
  * Port QStringRef (deprecated) to QStringView
  * [FFmpegExtractor] Remove FFmpeg 2.x/3.0 support, handle deprecations
  * Fix version checks in FindFFmpeg.cmake
  * [DublinCore] Also test terms namespace
  * [PopplerExtractor] directly use getters provided by poppler
  * Add FreeBSD CI
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * replace "MacOSX" with "macOS"
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- No code change since 5.84.0
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Fix compilation with libc++ also for autotests (semitested)
  * Fix compilation with libc++ (untested)
  * Update IRC network name in the README
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Bump required CMake version to 3.16
  * Call ki18n_install() unconditionally
  * [ExtractionResult] Remove automatic mimetype determination
  * [ExternalWriter] Test property serialization
  * [ExternalExtractor/Writer] Avoid unnecessary map value lookup from key
  * [ExternalWriter] Fix infinite loop when serializing properties
  * Avoid leaking a QObject in ExternalWriter
  * [TaglibExtractor] Rename ASF test case to WMA
  * [TaglibWriter] Fix memory leak when updating Cover images in ASF (WMA)
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * Use new version-controlled enumerator deprecation warning macros
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * This method is unused (fix unity compile support)
  * Enable Unicode support in QRegularExpression where needed
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Changes since 5.79.0:
  * [FFmpegExtractor] Use categorized logging
  * Enable CI, add .gitlab-ci.yml
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * ffmpegextractor: Use av_find_default_stream_index to find video stream
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Remove not implemented method
  * Remove ifdefs, we require Qt 5.14 now
* Sat Dec  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * Port some deprecated method
  * Fix some leaks in OpenDocument and Office OpenXML extractors
  * Add several subtypes for OpenDocument and OpenXML document
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Too many changes to list here.
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- No code change since 5.74.0
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Add missing include for OpenBSD
  * Use Q_DECLARE_OPERATORS_FOR_FLAGS in same namespace as flags definition
  * Convert old Mac line endings in lyrics tags (kde#425563)
  * Remove obsolete COPYING files
  * Port to ECM new FindTaglib module
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use KF-standardized Qt logging categories
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * autotests: fix for shared-mime-info >= 2.0
  * Adapt kfilemetadata to "audio/x-speex+ogg" as
    recently changed in shared-mime-info
  * Add license files as required by REUSE specification
  * Convert license statements to SPDX expressions
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * [TaglibExtractor] Add support for Audible "Enhanced Audio" audio books
  * test the extractNothing flag
  * honor the extractMetaData flag
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- No code change since 5.69.0
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- No code change since 5.68.0
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Use ecm_qt_install_logging_categories over manual categories file
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * Port away from deprecated QList::toSet() method
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * In qt5.15 QHash::insertMulti is deprecated now we need to use QMultiHash
  * Port QRegExp to QRegularExpression
  * partial fix for accentuated characters in file name on Windows
  * Port deprecated QSet::toList method
  * Update the obsolete projects.kde.org URL
  * Remove unrequired private declarations for taglibextractor
  * partial solution to accept accentuated characters on windows
  * xattr: fix crash on dangling symlinks (kde#414227)
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * xattr: fix crash on dangling symlinks (kde#414227)
  * disable writercollectiontest when taglib is not installed
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Use ECMGenerateExportHeader to manage deprecated API better
  * Fix crash in writer collection and cleanup
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Small performance improvements suggested by clang tidy
  * Port away from deprecated QDateTime::setUtcOffset
* Wed Sep 11 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Drop Qt5Multimedia BuildRequires, not used since KF 5.41.
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Implement writing of images
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * add missing semicolon
  * Get mobipocket extractor up-to-date, but keep disabled
  * taglibextractortest.cpp - fix build with include <QSet>
  * Remove unused includes
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Fix extracting of some properties to match what was written (kde#408532)
  * Use debugging category in taglib extractor/writer
  * Format photo exposure bias value
  * [XAttr] Probably fix build on Windows
  * fix property name
  * Remove photo prefix from every exif property name
  * Rename ImageMake and ImageModel properties
  * [UserMetaData] Add method to query which attributes are set
  * Format focal length as milli meter
  * Install in new logging directory when we use kf5 5.59.0
  * Format photo exposure time as rational when applicable
  * Enable usermetadatawritertest for all UNIXes, not only Linux.
  * Format the aperture values as F numbers.
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Show 3 significant figures when displaying doubles
  * clarify and document method
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Reorder includes
  * [TaglibExtractor] Feed non-ogg *.spx file into extractor test
  * [TagLibExtractor] Fix crash on invalid Speex files (kde#403902)
  * Fix exivextractor crash with malformed files (kde#405210)
  * Declare properties as meta type
  * Change properties attributes for consistency
  * Handle variant list in formatting functions
  * add license to python test files
  * Force en locale for propertyinfotest
  * Fix for Windows' stupid LARGE_INTEGER type
  * Fix (compilation) errors for Windows UserMetaData implementation
  * remove unnecessary parenthesis
  * add missing mimetype to taglib writer
  * Test all extractors with strict mime type
  * fix warnings
  * Use new mimetype helper in taglib extractor test
  * [UserMetaData] Handle changes in attribute data size correctly
  * [UserMetaData] Untangle Windows, Linux/BSD/Mac and stub code.
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Too many changes to list here
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * cleanup and slightly enhance display formatting test
  * Fix typo in exiv extractor
  * [Extractor] Add metadata to extractors
  * add test which checks the property types
  * Add extractor for AppImage files
  * Cleanup ffmpeg extractor
  * Add a test for ffmpeg extractor
  * [ExternalExtractor] Provide more helpful output when extractor fails
  * Fix minor typo
  * Format EXIF photo flash data
  * Fix build with cmake 3.5
  * Avoid side effects due to stale errno value
  * Try to fix test on windows
  * Use Kformat for bit and sample rate
  * Add units to framerate and gps data
  * Add string formatting function to property info
  * Avoid leaking a QObject in ExternalExtractor
  * Handle <a> as container element in SVG
  * Check Exiv2::ValueType::typeId before converting it to rational
- Dropped patches, now upstream:
  * fix-build-with-cmake-3.5.patch
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Tue Feb 12 2019 wbauer@tmo.at
- Add fix-build-with-cmake-3.5.patch to fix build with cmake 3.5.2
  on Leap 42.3
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * harmonize testing data
  * exiv2extractor: add support for bmp, gif, webp, tga
  * Fix failing test of exiv gps data
  * Test empty and zero gps data
  * Remove explicit use of ECM_KDE_MODULE_DIR, is part of ECM_MODULE_PATH
  * Use more https in links
  * add support for more mimetypes to taglibwriter
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Fix some warnings
  * fail writing test if mime type is not supported by the extractor
  * fix ape disc number extraction
  * implement cover extraction for asf files
  * extend list of supported mimetypes for embedded image extractor
  * Refactor embedded image extractor for greater extensibility
  * add missing wav mimetype
  * Extract more tags from exif metadata (kde#341162)
  * fix extraction of GPS altitude for exif data
* Sat Dec 15 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summaries.
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty()
  * Adapt to the FindExiv2 -> FindLibExiv2 name change in ECM.
  * Use the new FindExiv2 module from ECM.
  * Revive 'Description' property for DublinCore metadata
  * add a description property to KFileMetaData
  * [KFileMetaData] Add extractor for DSC conforming (Encapsulated) Postscript
  * rename variable
  * remove unneeded comment
  * cleanup the test for embedded image extraction
  * Add missing override
  * [ExtractorCollection] Avoid dependency of kcoreaddons for CI tests
  * Add support for speex files to taglibextractor
  * add two more internet sources regarding tagging information
  * fix alphabetical order
  * remove unused include
  * use qlatin1 for embedded image extractor
  * move supported mimetypes to static string list
  * create a separate test file for embedded images test
  * simplify handling of id3 tags
  * add explicit to constructors
  * add missing license information
  * [XmlExtractor] Use QXmlStreamReader for better performance
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Too many changes to list here
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * remove own implementation of QString to TString conversion for taglibwriter
  * increase test coverage of taglibwriter
  * implement more basic tags for taglibwriter
  * remove usage of own TString to QString conversion function
  * bump required taglib version to 1.11.1
  * implement reading of the replaygain tags
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * add missing include
  * Add enum alias Property::Language for typo Property::Langauge
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * API dox: add @file to functions-only header to have doxygen cover those
* Thu Aug  9 2018 fabian@ritter-vogt.de
- Don't recommend catdoc, doesn't exist anymore (boo#1104264)
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Avoid compiler warnings for taglib headers
  * PopplerExtractor: use directly QByteArray() args instead of 0 pointers
  * Use more nullptr
  * taglibextractor: Restore extracting audio props without tags existing
  * OdfExtractor: deal with non-common prefix names
  * Don't add -ltag to the public link interface.
  * implement the lyrics tag for taglibextractor
  * OdfExtractor: fix typo with dc:language
  * automatic tests: do not embed EmbeddedImageData already in the library
  * add ability to read embedded cover files
  * implement reading of rating tag
  * check for needed version of libavcode, libavformat and libavutil
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Use override
  * check that ffmpeg is at least version 3.1 that introduce the API we require
  * split tests for better readability
  * search for album artist and albumartist tags in taglibextractor
  * popplerextractor: don't try to guess the title if there isn't one.
- Dropped patches, superseded by upstream changes:
  - ffmpeg-buildrequires.patch
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Add description and purpose to Xattr dep
  * extractors: Hide warnings from system headers
  * fix detection of taglib when compiling for Android
  * [API dox] Note CamelCase include commands for classes
  * Install pri file for qmake support & document it in metainfo.yaml
  * Make concatenated strings wrappable
  * ffmpegextractor: Silence deprecation warnings
  * autotests: Do not use QScopedPointer for plugins
  * taglibextractor: Fix empty genre bug
  * taglibextractortest: Add test for files with empty metadata
  * taglibextractortest: Add test for files with empty metadata
  * handle more tags in taglibextractor
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * taglibextractor: Refactor for better readability
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Fix build with >=attr-2.4.48
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Use more explicit
  * Use more nullptr
  * Use nullptr, const'ify, port some Q_FOREACH to for(..:..)
  * Fix build against TagLib < 1.11
  * remove extractor based on QtMultimedia
  * Check for Linux instead of TagLib and avoid building the usermetadatawritertest on Windows.
  * Restore # 6c9111a9 until a successful build and link without TagLib is possible.
  * Remove the taglib dependency, caused by a left-over include. Also reverts commit # 6c9111a9
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * The usermetadatawritertest requires Taglib. Therefore if Taglib isn't around, we shouldn't try to build something that requires it. This fixes the build on Windows.
  * Port to debug category
  * Fix UserMetaData unit tests.
  * User meta data (xattr key-value) unit tests.
  * Simplify empty rating check.
  * If the property value is null, remove the user.xdg.tag attribute. (kde#376117)
  * Open files in TagLib extractor readonly
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Fix display name of Generator property
  * Add .arcconfig
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * fix crash when more than one instances of ExtractorCollection are destructed
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
  * in automatic tests, find python interpreter and use it for python test scripts
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Fix Python dependency in test scripts for KFileMetaData (bug 375472)
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Fix configure with Qt5Multimedia disabled.
  * add an extractor using qtmultimedia
  * [FEATURE] Option to build & install QCH file with the public API dox
  * fix warnings from clazy with the default warning level
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * use /usr/bin/env to locate python2
  * Use right QProcess API
  * fix build against Android NDK (API Level 21 is required)
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Rename the translation template (avoid conflicts)
  * makes KArchive be optional and do not build extractors needing it
  * cmake: switch to the FindPoppler module from ECM
  * fix duplicated symbols compilation error with mingw on Windows
  * autotests: Use QTEST_GUILESS_MAIN
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Make PlainTextExtractor match "text/plain" again
  * Upgrade KF5 version to 5.33.0.
- Remove patches, now upstream:
  * Make-PlainTextExtractor-match-text-plain-again.patch
* Mon Mar 20 2017 wbauer@tmo.at
- Add Make-PlainTextExtractor-match-text-plain-again.patch to fix
  metadata extraction for text files which got broken in 5.32.0
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
  * fix build of kfilemetadata with taglib version 1.9
  * New maintainer for kfilemetadata
  * [ExtractorCollection] Use mimetype inheritance to return plugins
  * add a new property DiscNumber for audio files from multi-disc albums
  * add more audio format to automatic test and fix problems
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Actually find FFMpeg's libpostproc
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Improve epub extractor, less segfaults (kde#361727)
  * Make odf indexer more error prove, check if the files are there
    (and are files at all) (meta.xml + content.xml)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Only require Xattr if the operating system is Linux
  * Restore Windows build
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Check for xattr during config step, otherwise the build
    might fail (if xattr.h is missing)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Mon Jul 25 2016 olaf@aepfle.de
- Build with ffmpeg unconditional
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
- Remove rpmlintrc file, it is not needed any more now
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Fixed external plugins and tests
  * Added support for external writer plugins
  * Added writer plugin support
  * Add external extractor plugin support
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Sun Apr 17 2016 olaf@aepfle.de
- Use pkgconfig instead of libffmpeg-devel
  ffmpeg-buildrequires.patch
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * KFileMetadata can now query and store information about the
    original email a saved file may have been an attachment of
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Allow querying for a file's origin URL
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Mon Jan 11 2016 wbauer@tmo.at
- Build against poppler-qt5 on SLE12 and Leap 42 as well, it is
  available meanwhile (boo#953957)
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Mark m4a as readable by taglib
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Implement windows usermetadata
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * PlainTextExtractor: enable O_NOATIME branch on GNU libc platforms
  * PlainTextExtractor: make the Linux branch work also without O_NOATIME
  * PlainTextExtractor: fix error check on open(O_NOATIME) failure
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Fri Sep  4 2015 hrvoje.senjan@gmail.com
- Only Recommend catdoc, to help reducing liveCD/DVD size
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul 26 2015 hrvoje.senjan@gmail.com
- Fix Oboletes/Provides versions regarding Leap versioning
* Mon Jul 20 2015 mlin@suse.com
- No poppler-qt5 in Leap 42, do not build with it on 42 and SLE
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Update required taglib version to 1.9
- Added libattr-devel BuildRequires
* Tue Mar 31 2015 hrvoje.senjan@gmail.com
- Enable ffmpeg support on openSUSE > 13.2
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Add lang subpackage
- Add rpmlintrc file for file-not-in-%%lang warnings: we don't use
  find_lang macro as it doesn't searches in subdirectories
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Unconditionally BuildRequire pkgconfig(poppler-qt5)
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Thu Sep 25 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Minor API adjustements since previous snapshot
* Thu Sep 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95~git20140911 (r5d1c60d):
  * Use QPluginLoader instead of KService for loading the plugins.
  * API cleanups
- Drop kservice-devel BuildRequires, per upstream changes
- Add baselibs.conf
* Sun Aug 10 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Bugfix release
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * Plasma 5 RC release
* Tue Jun  3 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0
  * Beta 2 of Plasma 5 release
- Add Source URL
* Sat May 17 2014 hrvoje.senjan@gmail.com
- Activate kfilemetadata5 package
